@@ -3,9 +3,9 @@
 use glib::{prelude::*, subclass::prelude::*, translate::*};
 
 use super::prelude::*;
-use crate::Pad;
+use crate::{ffi, Pad};
 
-pub trait PadImpl: PadImplExt + GstObjectImpl + Send + Sync {
+pub trait PadImpl: GstObjectImpl + ObjectSubclass<Type: IsA<Pad>> {
     fn linked(&self, peer: &Pad) {
         self.parent_linked(peer)
     }
@@ -15,13 +15,7 @@ pub trait PadImpl: PadImplExt + GstObjectImpl + Send + Sync {
     }
 }
 
-pub trait PadImplExt: ObjectSubclass {
-    fn parent_linked(&self, peer: &Pad);
-
-    fn parent_unlinked(&self, peer: &Pad);
-}
-
-impl<T: PadImpl> PadImplExt for T {
+pub trait PadImplExt: PadImpl {
     fn parent_linked(&self, peer: &Pad) {
         unsafe {
             let data = Self::type_data();
@@ -57,6 +51,8 @@ impl<T: PadImpl> PadImplExt for T {
     }
 }
 
+impl<T: PadImpl> PadImplExt for T {}
+
 unsafe impl<T: PadImpl> IsSubclassable<T> for Pad {
     fn class_init(klass: &mut glib::Class<Self>) {
         Self::parent_class_init::<T>(klass);
@@ -141,7 +137,7 @@ mod tests {
 
         assert_eq!(pad.name(), "test");
 
-        let otherpad = Pad::new(Some("other-test"), PadDirection::Sink);
+        let otherpad = Pad::builder(PadDirection::Sink).name("other-test").build();
         pad.link(&otherpad).unwrap();
         pad.unlink(&otherpad).unwrap();
 
